@@ -9,12 +9,16 @@ from tests.conftest import Net
 from unittest import mock
 import torch
 
-device = torch.device("cuda") if torch.cuda.is_available() else torch.device("cpu")
+device = (
+    torch.device("cuda") if torch.cuda.is_available() else torch.device("cpu")
+)
 
 
 # def test_TBPTT():
-#     mock_criterion = mock.Mock(return_value=torch.ones([1], requires_grad=True))
-#     mock_optimizer = mock.Mock(**{"zero_grad.return_value": 1, "step.return_value": 2})
+#     mock_criterion = mock.Mock(
+#     return_value=torch.ones([1], requires_grad=True))
+#     mock_optimizer = mock.Mock(**{
+#     "zero_grad.return_value": 1, "step.return_value": 2})
 #     criterion = mock_criterion
 #     optimizer = mock_optimizer
 #     net = Net().to(device)
